@@ -7,14 +7,15 @@ package Comics::Plugin::Glasbergen;
 
 use parent qw(Comics::Fetcher::Single);
 
-our $VERSION = "1.03";
+our $VERSION = "1.04";
 
 our $name    = "Glasbergen";
-our $url     = "http://www.glasbergen.com";
+our $url     = "https://www.glasbergen.com";
 our $pattern =
-	    qr{ <div \s+ class="ngg-widget \s+ entry-content" \s* > \s*
-		<a \s+ href="(?<url>https?://www.glasbergen.com/wp-content/
-		gallery/cartoons/(?<image>.+?))" \s*
+	    qr{ <meta \s+
+		 name="twitter:image" \s+
+		 content="(?<url>https?://www.glasbergen.com/wp-content/
+		     uploads/\d+/\d+/(?<image>.+?))"
 	      }x;
 
 # Important: Return the package name!
